#[non_exhaustive]pub enum CountMetric {
MethodCount,
FieldCount,
LinesOfCode,
Statements,
Imports,
ConcreteTypes,
Functions,
Traits,
ImplBlocks,
Macros,
AssociatedFunctions,
}Expand description
A built-in count metric and its valid Rust subject population.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MethodCount
Methods with a self receiver per type.
FieldCount
Declared data fields per type.
LinesOfCode
Physical non-comment source lines per file.
Statements
Syntax-tree items and executable statements per file.
Imports
use and extern crate items per file.
ConcreteTypes
Structs, enums, and unions per file.
Functions
Free functions per file.
Traits
Trait declarations per file.
ImplBlocks
Inherent and trait impl blocks per file.
Macros
Macro invocations per file.
AssociatedFunctions
Receiver-free functions in traits and impl blocks per file.
Implementations
Sourceimpl CountMetric
impl CountMetric