#[non_exhaustive]pub enum ExtractionDiagnosticKind {
ReadFile,
ParseFile,
MissingModule,
AmbiguousModule,
ModuleCycle,
InvalidPathAttribute,
AmbiguousReference,
UnknownReference,
}Expand description
The category of a non-fatal source extraction diagnostic.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ReadFile
A source file could not be read.
ParseFile
syn could not parse a source file.
MissingModule
An outlined module declaration had no matching source file.
AmbiguousModule
Both supported outlined module layouts matched one declaration.
ModuleCycle
Following module declarations would revisit a file in the same module ancestry.
InvalidPathAttribute
A #[path] attribute was not a literal string.
AmbiguousReference
A qualified path matched more than one viable internal or Cargo-visible target.
UnknownReference
A path’s first segment matched neither an internal module nor Cargo’s external prelude.
Implementations