#[non_exhaustive]pub enum LayerDependencyRule {
MayOnlyDependOnLayers,
MayNotDependOnLayers,
}Expand description
The named-layer policy that rejected a dependency.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MayOnlyDependOnLayers
The target layer was absent from the source layer’s allowlist.
MayNotDependOnLayers
The target layer was present in the source layer’s blocklist.
Implementations