#[non_exhaustive]pub enum LogFileMode {
Append,
Overwrite,
}Expand description
Initialization policy for an existing per-options log file.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Append
Retain existing content and add this logging session after it.
Overwrite
Truncate existing content exactly once before this logging session’s first record.