#[non_exhaustive]pub enum MetricComparison {
Below,
Above,
Equal,
BelowOrEqual,
AboveOrEqual,
}Expand description
One exact numeric relationship used by the five threshold verbs.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Below
The value must be strictly smaller than the threshold.
Above
The value must be strictly larger than the threshold.
Equal
The value must equal the threshold exactly.
BelowOrEqual
The value must be smaller than or equal to the threshold.
AboveOrEqual
The value must be larger than or equal to the threshold.
Implementations
Sourceimpl MetricComparison
impl MetricComparison
Sourcepub fn is_satisfied(self, value: f64, threshold: f64) -> bool
pub fn is_satisfied(self, value: f64, threshold: f64) -> bool
Returns whether value satisfies this exact comparison against threshold.