archunit

Enum MetricSubject

#[non_exhaustive]
pub enum MetricSubject { File(FileMetricsInfo), Type(TypeInfo), Distance(DistanceInfo), }
The extracted subject measured by a metric.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


File(FileMetricsInfo)

One source file.



Type(TypeInfo)

One Rust type declaration.



Distance(DistanceInfo)

One file-level component with its project coupling evidence.

Implementations

Source

impl MetricSubject

pub fn identifier(&self) -> &str

Returns the stable file path or module-qualified type name.

pub const fn as_file(&self) -> Option<&FileMetricsInfo>

Returns the file subject, if this measurement is file-level.

pub const fn as_type(&self) -> Option<&TypeInfo>

Returns the type subject, if this measurement is type-level.

pub const fn as_distance(&self) -> Option<&DistanceInfo>

Returns the component distance subject, if this measurement uses project coupling.