#[non_exhaustive]pub enum PatternTarget {
Filename,
Path,
PathWithoutFilename,
TypeName,
}Expand description
The part of an identifier against which a crate::Pattern is matched.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Filename
The last path segment, such as handler.rs.
Path
The complete normalized path.
PathWithoutFilename
The path with its final filename removed.
TypeName
A Rust type name with module or path qualification removed.
Implementations