archunit

Function build_distance_infos

pub fn build_distance_infos(
    metrics: &ProjectMetricsInfo,
    graph: &Graph,
) -> Vec<DistanceInfo>
Combines an already extracted syntax snapshot and dependency graph into distance inputs.

Only distinct internal, non-self file dependencies contribute to coupling. Graph endpoints absent from the metrics snapshot and all external dependencies are ignored.