pub fn extract_graph(
project: &CargoProject,
source_options: SourceOptions,
) -> Result<GraphExtraction, ArchUnitError>Expand description
Extracts or reuses the graph for one Cargo project and source configuration.
pub fn extract_graph(
project: &CargoProject,
source_options: SourceOptions,
) -> Result<GraphExtraction, ArchUnitError>Extracts or reuses the graph for one Cargo project and source configuration.