archunit

Function locate_project

pub fn locate_project() -> Result<CargoProject, ArchUnitError>
Locates the Cargo project above the current working directory.

Cargo metadata is the authority for workspace membership, targets, and the final workspace root.