pub fn project_files_in(path: impl Into<PathBuf>) -> FileConditionBuilderExpand description
Starts a file architecture rule at an explicit directory or Cargo.toml manifest.
pub fn project_files_in(path: impl Into<PathBuf>) -> FileConditionBuilderStarts a file architecture rule at an explicit directory or Cargo.toml manifest.