pub fn project_slices_in(path: impl AsRef<Path>) -> SliceScopeBuilderExpand description
Starts a lazy slice architecture scope at an explicit directory or Cargo manifest.
pub fn project_slices_in(path: impl AsRef<Path>) -> SliceScopeBuilderStarts a lazy slice architecture scope at an explicit directory or Cargo manifest.