pub fn slice_by_file_suffix<I, S, L>(
labeling: I,
) -> Result<SliceProjection, SliceProjectionError>Expand description
Maps Rust filename stems to slices by their longest matching suffix.
pub fn slice_by_file_suffix<I, S, L>(
labeling: I,
) -> Result<SliceProjection, SliceProjectionError>Maps Rust filename stems to slices by their longest matching suffix.