pub fn slice_by_regex(
expression: impl Into<PatternSpec>,
) -> Result<SliceProjection, SliceProjectionError>Expand description
Captures a slice name through the first group in a Rust regular expression.
pub fn slice_by_regex(
expression: impl Into<PatternSpec>,
) -> Result<SliceProjection, SliceProjectionError>Captures a slice name through the first group in a Rust regular expression.