pub fn validate_metric_threshold(
threshold: f64,
) -> Result<(), MetricThresholdError>Expand description
Validates the finite threshold required by every threshold terminal.
pub fn validate_metric_threshold(
threshold: f64,
) -> Result<(), MetricThresholdError>Validates the finite threshold required by every threshold terminal.