#[non_exhaustive]pub struct CargoProject { /* private fields */ }Expand description
Cargo’s authoritative description of the selected workspace.
Implementations
Sourceimpl CargoProject
impl CargoProject
Sourcepub fn manifest_path(&self) -> &Path
pub fn manifest_path(&self) -> &Path
Returns the workspace manifest, including for a virtual workspace.
Sourcepub fn target_directory(&self) -> &Path
pub fn target_directory(&self) -> &Path
Returns Cargo’s configured build-output directory.
Sourcepub fn member_roots(&self) -> impl ExactSizeIterator<Item = &Path>
pub fn member_roots(&self) -> impl ExactSizeIterator<Item = &Path>
Returns the absolute roots of workspace member packages in deterministic order.
Sourcepub fn targets(&self) -> &[CargoTarget]
pub fn targets(&self) -> &[CargoTarget]
Returns all target roots Cargo reported, including development-only targets.
Sourcepub fn source_targets(
&self,
options: SourceOptions,
) -> impl Iterator<Item = &CargoTarget>
pub fn source_targets( &self, options: SourceOptions, ) -> impl Iterator<Item = &CargoTarget>
Returns target roots selected by the source analysis options.