archunit

Struct CustomFileViolation

#[non_exhaustive]
pub struct CustomFileViolation { pub file_info: FileInfo, pub message: String, pub is_negated: bool, }
One selected file that disagrees with a user-defined predicate.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
file_info: FileInfo

The immutable file facts supplied to the predicate.

message: String

The user’s description of the predicate requirement.

is_negated: bool

Whether satisfying the predicate was forbidden rather than required.

Implementations

Source

impl CustomFileViolation

pub fn new( file_info: FileInfo, message: impl Into<String>, is_negated: bool, ) -> Self

Creates data for one file that failed a custom rule.