#[non_exhaustive]pub struct CustomMetricViolation {
pub type_info: TypeInfo,
pub metric_name: String,
pub description: String,
pub value: f64,
}Expand description
A Rust type whose custom metric value did not satisfy a user predicate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type_info: TypeInfoThe complete immutable Rust type evidence supplied to both callbacks.
metric_name: StringThe user-defined metric name.
description: StringThe user-defined metric description.
value: f64The calculated value rejected by the predicate.
Implementations