pub struct DependOnExternalModuleCondition { /* private fields */ }Expand description
Executable rule over dependencies from project files to external crates.
Implementations
Sourceimpl DependOnExternalModuleCondition
impl DependOnExternalModuleCondition
Sourcepub const fn builder(&self) -> &DependOnExternalModuleConditionBuilder
pub const fn builder(&self) -> &DependOnExternalModuleConditionBuilder
Returns the object-stage builder that owns the subject scope and mood.
Sourcepub const fn project_locator(&self) -> &ProjectLocator
pub const fn project_locator(&self) -> &ProjectLocator
Returns where Cargo project discovery begins.
Sourcepub fn subject_filters(&self) -> &[Filter]
pub fn subject_filters(&self) -> &[Filter]
Returns the subject-file filters in chain order.
Sourcepub fn module_filters(&self) -> &[Filter]
pub fn module_filters(&self) -> &[Filter]
Returns the external-crate filters in chain order.
These filters combine with OR semantics.
Sourcepub const fn is_negated(&self) -> bool
pub const fn is_negated(&self) -> bool
Returns whether matching crate dependencies are forbidden rather than allowed.
Sourcepub fn selector_error(&self) -> Option<&PatternError>
pub fn selector_error(&self) -> Option<&PatternError>
Returns the first invalid subject or module selector in sentence order.
Sourcepub fn matching(self, pattern: impl Into<PatternSpec>) -> Self
pub fn matching(self, pattern: impl Into<PatternSpec>) -> Self
Adds another external crate pattern using OR semantics.