pub struct DependOnFileCondition { /* private fields */ }Expand description
Executable rule over dependencies between project files.
Implementations
Sourceimpl DependOnFileCondition
impl DependOnFileCondition
Sourcepub const fn builder(&self) -> &DependOnFileConditionBuilder
pub const fn builder(&self) -> &DependOnFileConditionBuilder
Returns the object-stage builder that owns the subject scope and mood.
Sourcepub const fn project_locator(&self) -> &ProjectLocator
pub const fn project_locator(&self) -> &ProjectLocator
Returns where Cargo project discovery begins.
Sourcepub fn subject_filters(&self) -> &[Filter]
pub fn subject_filters(&self) -> &[Filter]
Returns the subject-file filters in chain order.
Sourcepub fn object_filters(&self) -> &[Filter]
pub fn object_filters(&self) -> &[Filter]
Returns the dependency-target filters in chain order.
Sourcepub const fn is_negated(&self) -> bool
pub const fn is_negated(&self) -> bool
Returns whether matching object dependencies are forbidden rather than allowed.
Sourcepub fn selector_error(&self) -> Option<&PatternError>
pub fn selector_error(&self) -> Option<&PatternError>
Returns the first invalid subject or object selector in sentence order.
Sourcepub fn with_name(self, pattern: impl Into<PatternSpec>) -> Self
pub fn with_name(self, pattern: impl Into<PatternSpec>) -> Self
Further restricts dependency targets by filename using AND semantics.
Sourcepub fn in_folder(self, pattern: impl Into<PatternSpec>) -> Self
pub fn in_folder(self, pattern: impl Into<PatternSpec>) -> Self
Further restricts dependency targets by containing folder using AND semantics.
Sourcepub fn in_path(self, pattern: impl Into<PatternSpec>) -> Self
pub fn in_path(self, pattern: impl Into<PatternSpec>) -> Self
Further restricts dependency targets by complete path using AND semantics.