archunit

Struct DiagramAdherenceOptions

#[non_exhaustive]
pub struct DiagramAdherenceOptions { pub ignore_orphan_slices: bool, pub ignore_external_slices: bool, }
Immutable modifiers controlling PlantUML diagram adherence.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
ignore_orphan_slices: bool

Ignore dependencies when either endpoint is absent from the diagram component set.

ignore_external_slices: bool

Ignore projected dependencies carrying external Cargo edge evidence.

Implementations

Source

impl DiagramAdherenceOptions

pub const fn new() -> Self

Creates strict diagram adherence options.

pub const fn with_orphan_slices_ignored(self, ignored: bool) -> Self

Returns a value configured to ignore or enforce undeclared slice endpoints.

pub const fn with_external_slices_ignored(self, ignored: bool) -> Self

Returns a value configured to ignore or enforce external Cargo dependencies.