#[non_exhaustive]pub struct ExternalModuleDependencyViolation {
pub dependency: ProjectedEdge,
pub is_negated: bool,
}Expand description
One external crate dependency that disagrees with a file rule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dependency: ProjectedEdgeThe projected dependency together with every raw Rust reference that produced it.
is_negated: boolWhether this dependency matched a forbidden crate rather than missing an allowed crate.
Implementations
Sourceimpl ExternalModuleDependencyViolation
impl ExternalModuleDependencyViolation
Sourcepub const fn new(dependency: ProjectedEdge, is_negated: bool) -> Self
pub const fn new(dependency: ProjectedEdge, is_negated: bool) -> Self
Creates data for one external dependency that failed a rule.