#[non_exhaustive]pub struct FileDependencyViolation {
pub dependency: ProjectedEdge,
pub is_negated: bool,
}Expand description
One internal file dependency that disagrees with a relational rule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dependency: ProjectedEdgeThe projected dependency together with every raw Rust reference that produced it.
is_negated: boolWhether this dependency matched a forbidden target rather than missing an allowed target.
Implementations
Sourceimpl FileDependencyViolation
impl FileDependencyViolation
Sourcepub const fn new(dependency: ProjectedEdge, is_negated: bool) -> Self
pub const fn new(dependency: ProjectedEdge, is_negated: bool) -> Self
Creates data for one dependency that failed a file rule.