archunit

Struct FileInfo

#[non_exhaustive]
pub struct FileInfo { pub path: String, pub name: String, pub extension: String, pub directory: String, pub content: String, pub non_blank_line_count: usize, }
Immutable source-file facts supplied to a user-defined predicate.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
path: String

The normalized workspace-relative identifier used by the graph and selectors.

name: String

The final filename with its last extension removed.

extension: String

The last filename extension, including its leading dot, or an empty string.

directory: String

The normalized containing directory, or . for a workspace-root file.

content: String

The complete UTF-8 source text exactly as read from disk.

non_blank_line_count: usize

The number of lines containing at least one non-whitespace character.

Implementations

Source

impl FileInfo

pub fn new(identifier: impl AsRef<str>, content: impl Into<String>) -> Self

Derives user-facing file facts from a graph identifier and its source text.