pub struct ForbiddenSliceDependencyCondition { /* private fields */ }Expand description
Executable slices should not contain dependency rule.
Implementations
Sourceimpl ForbiddenSliceDependencyCondition
impl ForbiddenSliceDependencyCondition
Sourcepub fn source_slice(&self) -> &str
pub fn source_slice(&self) -> &str
Returns the directed source slice named by the rule.
Sourcepub fn target_slice(&self) -> &str
pub fn target_slice(&self) -> &str
Returns the directed target slice named by the rule.
Sourcepub const fn project_locator(&self) -> &ProjectLocator
pub const fn project_locator(&self) -> &ProjectLocator
Returns where Cargo project discovery begins.
Sourcepub const fn projection(&self) -> &SliceProjection
pub const fn projection(&self) -> &SliceProjection
Returns the immutable file-to-slice projection.
Sourcepub const fn is_negated(&self) -> bool
pub const fn is_negated(&self) -> bool
Returns whether the fluent mood is negated.