archunit

Struct GraphRenderer

pub struct GraphRenderer;
Dispatches every output format from the same completed snapshot.

Implementations

Source

impl GraphRenderer

pub fn render( snapshot: &GraphReportSnapshot, format: GraphReportFormat, ) -> String

Renders snapshot as format.

pub fn to_dot(snapshot: &GraphReportSnapshot) -> String

Renders Graphviz DOT.

pub fn to_mermaid(snapshot: &GraphReportSnapshot) -> String

Renders Mermaid flowchart source.

pub fn to_d2(snapshot: &GraphReportSnapshot) -> String

Renders D2 diagram source.

pub fn to_csv(snapshot: &GraphReportSnapshot) -> String

Renders aggregated dependency CSV.

pub fn to_json(snapshot: &GraphReportSnapshot) -> String

Renders complete snapshot JSON.

pub fn to_html(snapshot: &GraphReportSnapshot) -> String

Renders a self-contained offline HTML report.

pub fn export( snapshot: &GraphReportSnapshot, format: GraphReportFormat, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>

Renders snapshot as format and writes it as UTF-8.

pub fn export_as_dot( snapshot: &GraphReportSnapshot, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>

Exports Graphviz DOT as UTF-8.

pub fn export_as_mermaid( snapshot: &GraphReportSnapshot, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>

Exports Mermaid flowchart source as UTF-8.

pub fn export_as_d2( snapshot: &GraphReportSnapshot, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>

Exports D2 diagram source as UTF-8.

pub fn export_as_csv( snapshot: &GraphReportSnapshot, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>

Exports aggregated dependency CSV as UTF-8.

pub fn export_as_json( snapshot: &GraphReportSnapshot, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>

Exports complete snapshot JSON as UTF-8.

pub fn export_as_html( snapshot: &GraphReportSnapshot, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>

Exports a self-contained offline HTML report as UTF-8.