#[non_exhaustive]pub struct GraphReportEdge {
pub source: String,
pub target: String,
pub count: usize,
pub external: bool,
pub import_kinds: ImportKindSet,
}Expand description
Aggregated dependency evidence in a graph report snapshot.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: StringCollapsed or original source-node label.
target: StringCollapsed or original target-node label.
count: usizeNumber of selected raw graph edges represented by this edge.
external: boolWhether at least one represented edge targets an external dependency.
import_kinds: ImportKindSetUnion of every Rust import kind represented by this edge.
Implementations
Sourceimpl GraphReportEdge
impl GraphReportEdge
Sourcepub fn new(
source: impl Into<String>,
target: impl Into<String>,
count: usize,
external: bool,
import_kinds: impl IntoIterator<Item = ImportKind>,
) -> Self
pub fn new( source: impl Into<String>, target: impl Into<String>, count: usize, external: bool, import_kinds: impl IntoIterator<Item = ImportKind>, ) -> Self
Creates one aggregated report edge.