#[non_exhaustive]pub struct ImplInfo { /* private fields */ }Expand description
One inherent or trait implementation block.
Implementations
Sourceimpl ImplInfo
impl ImplInfo
Sourcepub fn target_type(&self) -> &str
pub fn target_type(&self) -> &str
Returns the syntactic implementation target path.
Sourcepub fn trait_name(&self) -> Option<&str>
pub fn trait_name(&self) -> Option<&str>
Returns the implemented trait path, or None for an inherent impl.
Sourcepub fn methods(&self) -> &[MethodInfo]
pub fn methods(&self) -> &[MethodInfo]
Returns functions in this impl that have a self receiver.
Sourcepub fn associated_functions(&self) -> &[String]
pub fn associated_functions(&self) -> &[String]
Returns receiver-free associated function names.
Sourcepub const fn is_trait_impl(&self) -> bool
pub const fn is_trait_impl(&self) -> bool
Returns whether this is a trait implementation.