pub struct LayerDefinitionBuilder { /* private fields */ }Expand description
Immutable stage defining which files belong to one named layer.
Implementations
Sourceimpl LayerDefinitionBuilder
impl LayerDefinitionBuilder
Sourcepub fn defined_by(self, pattern: impl Into<PatternSpec>) -> LayeredArchitecture
pub fn defined_by(self, pattern: impl Into<PatternSpec>) -> LayeredArchitecture
Assigns files whose complete normalized path matches pattern to this layer.
Sourcepub fn defined_by_folder(
self,
pattern: impl Into<PatternSpec>,
) -> LayeredArchitecture
pub fn defined_by_folder( self, pattern: impl Into<PatternSpec>, ) -> LayeredArchitecture
Assigns files whose containing directory matches pattern to this layer.
Sourcepub const fn architecture(&self) -> &LayeredArchitecture
pub const fn architecture(&self) -> &LayeredArchitecture
Returns the architecture accumulated before this definition stage.
Sourcepub fn layer_name(&self) -> &str
pub fn layer_name(&self) -> &str
Returns the name of the layer being defined.