pub struct LcomMetricSelection { /* private fields */ }Expand description
One selected LCOM formula ready for extraction and measurement.
Implementations
Sourceimpl LcomMetricSelection
impl LcomMetricSelection
Sourcepub fn should_be_below(self, threshold: f64) -> MetricThresholdCondition<Self>
pub fn should_be_below(self, threshold: f64) -> MetricThresholdCondition<Self>
Requires every measured value to be strictly below threshold.
Sourcepub fn should_be_above(self, threshold: f64) -> MetricThresholdCondition<Self>
pub fn should_be_above(self, threshold: f64) -> MetricThresholdCondition<Self>
Requires every measured value to be strictly above threshold.
Sourcepub fn should_be(self, threshold: f64) -> MetricThresholdCondition<Self>
pub fn should_be(self, threshold: f64) -> MetricThresholdCondition<Self>
Requires every measured value to equal threshold exactly.
Sourcepub fn should_be_below_or_equal(
self,
threshold: f64,
) -> MetricThresholdCondition<Self>
pub fn should_be_below_or_equal( self, threshold: f64, ) -> MetricThresholdCondition<Self>
Requires every measured value to be below or equal to threshold.
Sourcepub fn should_be_above_or_equal(
self,
threshold: f64,
) -> MetricThresholdCondition<Self>
pub fn should_be_above_or_equal( self, threshold: f64, ) -> MetricThresholdCondition<Self>
Requires every measured value to be above or equal to threshold.
Sourcepub fn measure(&self) -> Result<Vec<MetricMeasurement>, ArchUnitError>
pub fn measure(&self) -> Result<Vec<MetricMeasurement>, ArchUnitError>
Extracts and measures eligible production-source structs.
Sourcepub fn measure_with(
&self,
check_options: &CheckOptions,
) -> Result<Vec<MetricMeasurement>, ArchUnitError>
pub fn measure_with( &self, check_options: &CheckOptions, ) -> Result<Vec<MetricMeasurement>, ArchUnitError>
Extracts and measures eligible structs with explicit source-target options.
Sourcepub const fn metric(&self) -> LcomMetric
pub const fn metric(&self) -> LcomMetric
Returns the selected LCOM formula.
Sourcepub fn should_satisfy<Predicate>(
self,
predicate: Predicate,
) -> MetricPredicateCondition<Self, Predicate>
pub fn should_satisfy<Predicate>( self, predicate: Predicate, ) -> MetricPredicateCondition<Self, Predicate>
Creates a reusable predicate over each value and complete type subject.