pub struct MatchPatternFileCondition { /* private fields */ }Expand description
Executable filename, folder, or path predicate for selected files.
Implementations
Sourceimpl MatchPatternFileCondition
impl MatchPatternFileCondition
Sourcepub const fn condition(&self) -> &MatchPatternFileConditionBuilder
pub const fn condition(&self) -> &MatchPatternFileConditionBuilder
Returns the selected scope and mood carried into this terminal.
Sourcepub fn check_filter(&self) -> Option<&Filter>
pub fn check_filter(&self) -> Option<&Filter>
Returns the compiled predicate filter, if its pattern was valid.
Sourcepub const fn project_locator(&self) -> &ProjectLocator
pub const fn project_locator(&self) -> &ProjectLocator
Returns where Cargo project discovery begins.
Sourcepub const fn is_negated(&self) -> bool
pub const fn is_negated(&self) -> bool
Returns whether matching the predicate is forbidden rather than required.
Sourcepub fn selector_error(&self) -> Option<&PatternError>
pub fn selector_error(&self) -> Option<&PatternError>
Returns the first invalid pattern in sentence order.