#[non_exhaustive]pub struct MetricMeasurement { /* private fields */ }Expand description
One numeric metric value and the complete subject that produced it.
Implementations
Sourceimpl MetricMeasurement
impl MetricMeasurement
Sourcepub const fn subject(&self) -> &MetricSubject
pub const fn subject(&self) -> &MetricSubject
Returns the measured subject.
Sourcepub fn identifier(&self) -> &str
pub fn identifier(&self) -> &str
Returns the file path or type name identifying the subject.
Sourcepub fn metric_name(&self) -> &str
pub fn metric_name(&self) -> &str
Returns the stable metric name.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the metric description.