#[non_exhaustive]pub struct MetricPredicateViolation {
pub subject: MetricSubject,
pub metric_name: String,
pub value: f64,
}Expand description
One built-in metric value that did not satisfy a user predicate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.subject: MetricSubjectThe complete file, type, or distance subject evidence.
metric_name: StringThe stable built-in metric name.
value: f64The value rejected by the predicate.
Implementations
Sourceimpl MetricPredicateViolation
impl MetricPredicateViolation
Sourcepub fn new(
subject: MetricSubject,
metric_name: impl Into<String>,
value: f64,
) -> Self
pub fn new( subject: MetricSubject, metric_name: impl Into<String>, value: f64, ) -> Self
Creates structured predicate violation data.
Sourcepub fn identifier(&self) -> &str
pub fn identifier(&self) -> &str
Returns the file path or type name identifying the rejected subject.