#[non_exhaustive]pub struct MetricThresholdViolation {
pub subject: MetricSubject,
pub metric_name: String,
pub value: f64,
pub threshold: f64,
pub comparison: MetricComparison,
}Expand description
One metric value that did not meet its numeric threshold.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.subject: MetricSubjectThe complete metric subject evidence.
metric_name: StringThe stable built-in or user-defined metric name.
value: f64The measured value.
threshold: f64The required finite threshold.
comparison: MetricComparisonThe comparison that was not satisfied.
Implementations
Sourceimpl MetricThresholdViolation
impl MetricThresholdViolation
Sourcepub fn new(
subject: MetricSubject,
metric_name: impl Into<String>,
value: f64,
threshold: f64,
comparison: MetricComparison,
) -> Self
pub fn new( subject: MetricSubject, metric_name: impl Into<String>, value: f64, threshold: f64, comparison: MetricComparison, ) -> Self
Creates structured threshold violation data.
Sourcepub fn identifier(&self) -> &str
pub fn identifier(&self) -> &str
Returns the file path or type name identifying the rejected subject.