pub struct NegatedMatchPatternFileConditionBuilder { /* private fields */ }Expand description
The should_not mood for file predicates.
Implementations
Sourceimpl NegatedMatchPatternFileConditionBuilder
impl NegatedMatchPatternFileConditionBuilder
Sourcepub const fn condition(&self) -> &MatchPatternFileConditionBuilder
pub const fn condition(&self) -> &MatchPatternFileConditionBuilder
Returns the shared mood state.
Sourcepub const fn scope(&self) -> &FileConditionBuilder
pub const fn scope(&self) -> &FileConditionBuilder
Returns the selected file scope.
Sourcepub const fn is_negated(&self) -> bool
pub const fn is_negated(&self) -> bool
Returns true for the negated mood.
Sourcepub const fn project_locator(&self) -> &ProjectLocator
pub const fn project_locator(&self) -> &ProjectLocator
Returns where Cargo project discovery will begin.
Sourcepub const fn selector_error(&self) -> Option<&PatternError>
pub const fn selector_error(&self) -> Option<&PatternError>
Returns the first invalid selector retained by the scope.
Sourcepub fn have_name(
self,
pattern: impl Into<PatternSpec>,
) -> MatchPatternFileCondition
pub fn have_name( self, pattern: impl Into<PatternSpec>, ) -> MatchPatternFileCondition
Forbids selected files whose final path segment matches pattern.
Sourcepub fn be_in_folder(
self,
pattern: impl Into<PatternSpec>,
) -> MatchPatternFileCondition
pub fn be_in_folder( self, pattern: impl Into<PatternSpec>, ) -> MatchPatternFileCondition
Forbids selected files whose containing folder matches pattern.
Sourcepub fn be_in_path(
self,
pattern: impl Into<PatternSpec>,
) -> MatchPatternFileCondition
pub fn be_in_path( self, pattern: impl Into<PatternSpec>, ) -> MatchPatternFileCondition
Forbids selected files whose complete normalized path matches pattern.
Sourcepub fn depend_on_files(self) -> DependOnFileConditionBuilder
pub fn depend_on_files(self) -> DependOnFileConditionBuilder
Starts a denylist rule over dependencies from the selected files.
Sourcepub fn depend_on_external_modules(
self,
) -> DependOnExternalModuleConditionBuilder
pub fn depend_on_external_modules( self, ) -> DependOnExternalModuleConditionBuilder
Starts a denylist rule over external crate dependencies from the selected files.