pub struct PatternCollapse { /* private fields */ }Expand description
Collapses node labels through a regular-expression capture replacement.
Implementations
Sourceimpl PatternCollapse
impl PatternCollapse
Sourcepub const DEFAULT_REPLACEMENT: &'static str = "$1"
pub const DEFAULT_REPLACEMENT: &'static str = "$1"
The Rust regex spelling for the first capture group.
Sourcepub fn new(
expression: impl AsRef<str>,
replacement: impl Into<String>,
) -> Result<Self, GraphQueryError>
pub fn new( expression: impl AsRef<str>, replacement: impl Into<String>, ) -> Result<Self, GraphQueryError>
Compiles a collapse expression with an explicit Rust regex replacement.
Sourcepub fn first_capture(
expression: impl AsRef<str>,
) -> Result<Self, GraphQueryError>
pub fn first_capture( expression: impl AsRef<str>, ) -> Result<Self, GraphQueryError>
Compiles a collapse expression that replaces a match with its first capture group.
Sourcepub fn replacement(&self) -> &str
pub fn replacement(&self) -> &str
Returns the Rust regex replacement expression.