pub struct PlantUmlDiagram {
pub components: Vec<String>,
pub dependencies: Vec<PlantUmlDependency>,
}Expand description
Immutable components and allowed directed dependencies parsed from PlantUML.
Fields
components: Vec<String>Declared and dependency-implied component names in first-seen order.
dependencies: Vec<PlantUmlDependency>Unique allowed dependencies in first-seen order.
Implementations
Sourceimpl PlantUmlDiagram
impl PlantUmlDiagram
Sourcepub fn new<C, D>(components: C, dependencies: D) -> Result<Self, PlantUmlError>
pub fn new<C, D>(components: C, dependencies: D) -> Result<Self, PlantUmlError>
Creates a diagram, adding dependency endpoints to the component collection.