#[non_exhaustive]pub struct RegexFactoryOptions { /* private fields */ }Expand description
Options shared by every matcher produced by a RegexFactory.
Implementations
Sourceimpl RegexFactoryOptions
impl RegexFactoryOptions
Sourcepub const fn syntax(self, syntax: PatternSyntax) -> Self
pub const fn syntax(self, syntax: PatternSyntax) -> Self
Returns options configured to read user input as syntax.
Sourcepub const fn case_insensitive(self, enabled: bool) -> Self
pub const fn case_insensitive(self, enabled: bool) -> Self
Returns options configured for case-sensitive or case-insensitive matching.
Sourcepub const fn pattern_syntax(self) -> PatternSyntax
pub const fn pattern_syntax(self) -> PatternSyntax
Returns the selected input syntax.
Sourcepub const fn is_case_insensitive(self) -> bool
pub const fn is_case_insensitive(self) -> bool
Returns whether generated matchers ignore letter case.