#[non_exhaustive]pub struct SliceDependencyViolation {
pub dependency: ProjectedEdge,
pub source_slice: String,
pub target_slice: String,
pub rule: SliceDependencyRule,
pub is_negated: bool,
}Expand description
One projected slice dependency rejected by a slice architecture rule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dependency: ProjectedEdgeThe projected dependency and every concrete Rust file edge behind it.
source_slice: StringThe selected dependency source slice.
target_slice: StringThe selected dependency target slice or external crate.
rule: SliceDependencyRuleThe policy kind that rejected the dependency.
is_negated: boolWhether the fluent rule used the negated mood.
Implementations
Sourceimpl SliceDependencyViolation
impl SliceDependencyViolation
Sourcepub fn new(
dependency: ProjectedEdge,
source_slice: impl Into<String>,
target_slice: impl Into<String>,
rule: SliceDependencyRule,
is_negated: bool,
) -> Self
pub fn new( dependency: ProjectedEdge, source_slice: impl Into<String>, target_slice: impl Into<String>, rule: SliceDependencyRule, is_negated: bool, ) -> Self
Creates structured data for one rejected slice dependency.