#[non_exhaustive]pub struct SourceOptions { /* private fields */ }Expand description
Options that change Cargo source discovery.
Implementations
Sourceimpl SourceOptions
impl SourceOptions
Sourcepub const fn includes_dev_targets(self) -> bool
pub const fn includes_dev_targets(self) -> bool
Returns whether Cargo test, example, and benchmark targets are included.
Sourcepub const fn with_dev_targets(self, include: bool) -> Self
pub const fn with_dev_targets(self, include: bool) -> Self
Controls whether Cargo test, example, and benchmark targets are included.