archunit

Struct TestResultOptions

#[non_exhaustive]
pub struct TestResultOptions { /* private fields */ }
Presentation and expectation options for crate::ResultFactory.

Implementations

Source

impl TestResultOptions

pub const fn new() -> Self

Creates auto-colored output that expects the architecture rule to pass.

pub const fn color(self) -> ColorChoice

Returns the configured ANSI color policy.

pub const fn expects_to_pass(self) -> bool

Returns whether an empty violation list is expected.

pub const fn with_color(self, color: ColorChoice) -> Self

Selects the ANSI color policy.

pub const fn with_expected_to_pass(self, expected: bool) -> Self

Controls whether the architecture rule is expected to have no violations.