#[non_exhaustive]pub struct TypeInfo { /* private fields */ }Expand description
Metrics information for one Rust type declaration.
Implementations
Sourceimpl TypeInfo
impl TypeInfo
Sourcepub fn simple_name(&self) -> &str
pub fn simple_name(&self) -> &str
Returns the unqualified declared name.
Sourcepub fn methods(&self) -> &[MethodInfo]
pub fn methods(&self) -> &[MethodInfo]
Returns functions with a self receiver declared by or associated with this type.
Sourcepub fn inherent_methods(&self) -> &[MethodInfo]
pub fn inherent_methods(&self) -> &[MethodInfo]
Returns only methods declared in unambiguously associated inherent impl blocks.
Trait declarations and trait-impl methods remain visible through Self::methods but do
not participate in this collection.
Sourcepub fn associated_functions(&self) -> &[String]
pub fn associated_functions(&self) -> &[String]
Returns receiver-free associated function names.