pub fn locate_project() -> Result<CargoProject, ArchUnitError>Expand description
Locates the Cargo project above the current working directory.
Cargo metadata is the authority for workspace membership, targets, and the final workspace root.
pub fn locate_project() -> Result<CargoProject, ArchUnitError>Locates the Cargo project above the current working directory.
Cargo metadata is the authority for workspace membership, targets, and the final workspace root.