pub struct CountMetricsBuilder { /* private fields */ }Expand description
Built-in count choices over one immutable selection.
Implementations
Sourceimpl CountMetricsBuilder
impl CountMetricsBuilder
Sourcepub fn export_as_html(
self,
output_path: impl AsRef<Path>,
) -> Result<PathBuf, ArchUnitError>
pub fn export_as_html( self, output_path: impl AsRef<Path>, ) -> Result<PathBuf, ArchUnitError>
Exports every built-in count metric with default presentation options.
Sourcepub fn export_as_html_with(
self,
output_path: impl AsRef<Path>,
options: &MetricsExportOptions,
) -> Result<PathBuf, ArchUnitError>
pub fn export_as_html_with( self, output_path: impl AsRef<Path>, options: &MetricsExportOptions, ) -> Result<PathBuf, ArchUnitError>
Exports every built-in count metric with explicit presentation options.
Sourcepub fn method_count(self) -> MetricSelection
pub fn method_count(self) -> MetricSelection
Counts methods with a self receiver for every selected type.
Sourcepub fn field_count(self) -> MetricSelection
pub fn field_count(self) -> MetricSelection
Counts declared data fields for every selected type.
Sourcepub fn lines_of_code(self) -> MetricSelection
pub fn lines_of_code(self) -> MetricSelection
Counts physical non-comment source lines for every selected file.
Sourcepub fn statements(self) -> MetricSelection
pub fn statements(self) -> MetricSelection
Counts syntax-tree items and executable statements for every selected file.
Sourcepub fn imports(self) -> MetricSelection
pub fn imports(self) -> MetricSelection
Counts use and extern crate items for every selected file.
Sourcepub fn concrete_types(self) -> MetricSelection
pub fn concrete_types(self) -> MetricSelection
Counts structs, enums, and unions for every selected file.
Sourcepub fn functions(self) -> MetricSelection
pub fn functions(self) -> MetricSelection
Counts free functions for every selected file.
Sourcepub fn traits(self) -> MetricSelection
pub fn traits(self) -> MetricSelection
Counts trait declarations for every selected file.
Sourcepub fn impl_blocks(self) -> MetricSelection
pub fn impl_blocks(self) -> MetricSelection
Counts inherent and trait impl blocks for every selected file.
Sourcepub fn macros(self) -> MetricSelection
pub fn macros(self) -> MetricSelection
Counts macro invocations and definitions represented by syntax for every selected file.
Sourcepub fn associated_functions(self) -> MetricSelection
pub fn associated_functions(self) -> MetricSelection
Counts receiver-free functions in traits and impl blocks for every selected file.