pub struct DependOnFileConditionBuilder { /* private fields */ }Expand description
Immutable object stage selecting internal dependency targets.
Implementations
Sourceimpl DependOnFileConditionBuilder
impl DependOnFileConditionBuilder
Sourcepub const fn condition(&self) -> &MatchPatternFileConditionBuilder
pub const fn condition(&self) -> &MatchPatternFileConditionBuilder
Returns the subject scope and mood carried into this object stage.
Sourcepub const fn project_locator(&self) -> &ProjectLocator
pub const fn project_locator(&self) -> &ProjectLocator
Returns where Cargo project discovery begins.
Sourcepub fn subject_filters(&self) -> &[Filter]
pub fn subject_filters(&self) -> &[Filter]
Returns the subject-file filters in chain order.
Sourcepub const fn is_negated(&self) -> bool
pub const fn is_negated(&self) -> bool
Returns whether matching object dependencies are forbidden rather than allowed.
Sourcepub const fn selector_error(&self) -> Option<&PatternError>
pub const fn selector_error(&self) -> Option<&PatternError>
Returns the first invalid subject-scope selector.
Sourcepub fn with_name(self, pattern: impl Into<PatternSpec>) -> DependOnFileCondition
pub fn with_name(self, pattern: impl Into<PatternSpec>) -> DependOnFileCondition
Selects dependency targets whose final path segment matches pattern.
Sourcepub fn in_folder(self, pattern: impl Into<PatternSpec>) -> DependOnFileCondition
pub fn in_folder(self, pattern: impl Into<PatternSpec>) -> DependOnFileCondition
Selects dependency targets whose containing folder matches pattern.
Sourcepub fn in_path(self, pattern: impl Into<PatternSpec>) -> DependOnFileCondition
pub fn in_path(self, pattern: impl Into<PatternSpec>) -> DependOnFileCondition
Selects dependency targets whose complete normalized path matches pattern.