#[non_exhaustive]pub struct GraphQueryOptions { /* private fields */ }Expand description
Immutable selection, collapse, and presentation options for one graph snapshot.
Implementations
Sourceimpl GraphQueryOptions
impl GraphQueryOptions
Sourcepub const fn with_external_dependencies(self, include: bool) -> Self
pub const fn with_external_dependencies(self, include: bool) -> Self
Controls whether external dependency targets and edges appear.
Sourcepub const fn with_self_dependencies(self, include: bool) -> Self
pub const fn with_self_dependencies(self, include: bool) -> Self
Controls whether extracted and collapse-produced self edges appear.
Sourcepub fn with_focus(self, focus: Filter, depth: usize) -> Self
pub fn with_focus(self, focus: Filter, depth: usize) -> Self
Adds an undirected focus query expanded to depth neighbors.
Sourcepub fn with_reachable_from(self, reachable_from: Filter) -> Self
pub fn with_reachable_from(self, reachable_from: Filter) -> Self
Adds a transitive outgoing-dependency query.
Sourcepub fn with_dependents_of(self, dependents_of: Filter) -> Self
pub fn with_dependents_of(self, dependents_of: Filter) -> Self
Adds a transitive incoming-dependent query.
Sourcepub fn with_collapse(self, collapse: GraphCollapse) -> Self
pub fn with_collapse(self, collapse: GraphCollapse) -> Self
Selects one node-collapse strategy.
Sourcepub fn with_title(
self,
title: impl Into<String>,
) -> Result<Self, GraphQueryError>
pub fn with_title( self, title: impl Into<String>, ) -> Result<Self, GraphQueryError>
Sets a non-empty report title.
Sourcepub const fn includes_external_dependencies(&self) -> bool
pub const fn includes_external_dependencies(&self) -> bool
Returns whether external dependencies participate in this query.
Sourcepub const fn includes_self_dependencies(&self) -> bool
pub const fn includes_self_dependencies(&self) -> bool
Returns whether self dependencies participate in the report.
Sourcepub const fn focus_depth(&self) -> usize
pub const fn focus_depth(&self) -> usize
Returns the undirected focus expansion depth.
Sourcepub const fn reachable_from(&self) -> Option<&Filter>
pub const fn reachable_from(&self) -> Option<&Filter>
Returns the optional outgoing traversal selector.
Sourcepub const fn dependents_of(&self) -> Option<&Filter>
pub const fn dependents_of(&self) -> Option<&Filter>
Returns the optional incoming traversal selector.
Sourcepub const fn collapse(&self) -> Option<&GraphCollapse>
pub const fn collapse(&self) -> Option<&GraphCollapse>
Returns the optional node-collapse strategy.