pub struct GraphRenderer;Expand description
Dispatches every output format from the same completed snapshot.
Implementations
Sourceimpl GraphRenderer
impl GraphRenderer
Sourcepub fn render(
snapshot: &GraphReportSnapshot,
format: GraphReportFormat,
) -> String
pub fn render( snapshot: &GraphReportSnapshot, format: GraphReportFormat, ) -> String
Renders snapshot as format.
Sourcepub fn to_dot(snapshot: &GraphReportSnapshot) -> String
pub fn to_dot(snapshot: &GraphReportSnapshot) -> String
Renders Graphviz DOT.
Sourcepub fn to_mermaid(snapshot: &GraphReportSnapshot) -> String
pub fn to_mermaid(snapshot: &GraphReportSnapshot) -> String
Renders Mermaid flowchart source.
Sourcepub fn to_d2(snapshot: &GraphReportSnapshot) -> String
pub fn to_d2(snapshot: &GraphReportSnapshot) -> String
Renders D2 diagram source.
Sourcepub fn to_csv(snapshot: &GraphReportSnapshot) -> String
pub fn to_csv(snapshot: &GraphReportSnapshot) -> String
Renders aggregated dependency CSV.
Sourcepub fn to_json(snapshot: &GraphReportSnapshot) -> String
pub fn to_json(snapshot: &GraphReportSnapshot) -> String
Renders complete snapshot JSON.
Sourcepub fn to_html(snapshot: &GraphReportSnapshot) -> String
pub fn to_html(snapshot: &GraphReportSnapshot) -> String
Renders a self-contained offline HTML report.
Sourcepub fn export(
snapshot: &GraphReportSnapshot,
format: GraphReportFormat,
output_path: impl AsRef<Path>,
) -> Result<(), ArchUnitError>
pub fn export( snapshot: &GraphReportSnapshot, format: GraphReportFormat, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>
Renders snapshot as format and writes it as UTF-8.
Sourcepub fn export_as_dot(
snapshot: &GraphReportSnapshot,
output_path: impl AsRef<Path>,
) -> Result<(), ArchUnitError>
pub fn export_as_dot( snapshot: &GraphReportSnapshot, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>
Exports Graphviz DOT as UTF-8.
Sourcepub fn export_as_mermaid(
snapshot: &GraphReportSnapshot,
output_path: impl AsRef<Path>,
) -> Result<(), ArchUnitError>
pub fn export_as_mermaid( snapshot: &GraphReportSnapshot, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>
Exports Mermaid flowchart source as UTF-8.
Sourcepub fn export_as_d2(
snapshot: &GraphReportSnapshot,
output_path: impl AsRef<Path>,
) -> Result<(), ArchUnitError>
pub fn export_as_d2( snapshot: &GraphReportSnapshot, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>
Exports D2 diagram source as UTF-8.
Sourcepub fn export_as_csv(
snapshot: &GraphReportSnapshot,
output_path: impl AsRef<Path>,
) -> Result<(), ArchUnitError>
pub fn export_as_csv( snapshot: &GraphReportSnapshot, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>
Exports aggregated dependency CSV as UTF-8.
Sourcepub fn export_as_json(
snapshot: &GraphReportSnapshot,
output_path: impl AsRef<Path>,
) -> Result<(), ArchUnitError>
pub fn export_as_json( snapshot: &GraphReportSnapshot, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>
Exports complete snapshot JSON as UTF-8.
Sourcepub fn export_as_html(
snapshot: &GraphReportSnapshot,
output_path: impl AsRef<Path>,
) -> Result<(), ArchUnitError>
pub fn export_as_html( snapshot: &GraphReportSnapshot, output_path: impl AsRef<Path>, ) -> Result<(), ArchUnitError>
Exports a self-contained offline HTML report as UTF-8.