#[non_exhaustive]pub struct TestResultOptions { /* private fields */ }Expand description
Presentation and expectation options for crate::ResultFactory.
Implementations
Sourceimpl TestResultOptions
impl TestResultOptions
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates auto-colored output that expects the architecture rule to pass.
Sourcepub const fn color(self) -> ColorChoice
pub const fn color(self) -> ColorChoice
Returns the configured ANSI color policy.
Sourcepub const fn expects_to_pass(self) -> bool
pub const fn expects_to_pass(self) -> bool
Returns whether an empty violation list is expected.
Sourcepub const fn with_color(self, color: ColorChoice) -> Self
pub const fn with_color(self, color: ColorChoice) -> Self
Selects the ANSI color policy.
Sourcepub const fn with_expected_to_pass(self, expected: bool) -> Self
pub const fn with_expected_to_pass(self, expected: bool) -> Self
Controls whether the architecture rule is expected to have no violations.